﻿# Copyright 2012, Trimble Navigation Limited

# This software is provided as an example of using the Ruby interface
# to SketchUp.

# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted, provided that the above
# copyright notice appear in all copies.

# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#-----------------------------------------------------------------------------


# Slightly modified to fit special demands 
require 'sketchup.rb'




# Based on the Box-Example


def self.create_boden   

#set the component dictionary
@Component_dictionary = 'dynamic_attributes'

# First prompt for the dimensions.  This is done using the inputbox
    
# method.  In this case, we will actually use a wrapper for UI.inputbox
    
# that is defined in sketchup.rb which does some extra error checking
    
    
# The first step is to create some arrays which contain the prompts
    
# and default values.
    
prompts = [("Bemerkung"),("Artikel"),("Laenge"), ("Breite"),("Staerke"),("Kante_links"),("Kante_rechts"),("Kante_oben"),("Kante_unten"),("Belag_Vorn"),("Belag_hinten")]
    
values = ["BodenDecke","Material1", 600.mm, 400.mm, 19.mm,"Kante1", "Kante1","","","",""]
  
list = ["", "Material1|Material2|Material3|Material4|Material5|Material6", "", "", "","|Kante1|Kante2|Kante3|Kante4|Kante5|Kante6","|Kante1|Kante2|Kante3|Kante4|Kante5|Kante6","|Kante1|Kante2|Kante3|Kante4|Kante5|Kante6","|Kante1|Kante2|Kante3|Kante4|Kante5|Kante6","|Belag1|Belag2|Belag3|Belag4|Belag5|Belag6","|Belag1|Belag2|Belag3|Belag4|Belag5|Belag6"]  
   
results = UI.inputbox(prompts, values, list, "Corpora Bauteil horizontal")

# Note that for the default values, we specify the values like "6.feet"
    
# This says that the value is Length, and tells what the units of
    
# the Length are.  When you display a Length value in an input box, it
    
# will be formatted using your current units settings and it will parse
   
# the values that you enter as a Length.
    
    
# Now display the inputbox
    
#results = inputbox prompts, values, ("Bauteil-Abmessungen")
    
    

# The values that the user entered are returned in the results value.
    
# If the user hit the "Cancel" button, then the function will return
    
# nil.  Otherwise it is an array of values.  SKetchUp tries to match
    
# the type of the returned values with the types of the default value
    
# supplied, so in this case, since the default values were Lengths we
    
# will get back an Array of Lengths
    return if not results 
# This means that the user canceled the operation
    
    
bemerkung, artikel, laenge, breite, staerke, kante_links, kante_rechts, kante_oben, kante_unten, belag_vorn, belag_hinten = results
    
    

# Now we can actually create the new geometry in the Model.  There are
    
# a number of ways that we could actually create the geometry.  We will
    
# show a couple of ways.
    
    
# The first thing that we will do is bracket all of the entity creation
    
# so that this looks like a single operation for undo.  If we didn't do this
    
# you would get a whole bunch of separate undo items for each step
    
# of the entity creation.
    
model = Sketchup.active_model
    
model.start_operation $exStrings.GetString("Create Boden")
    
    

# We will add the new entities to the "active_entities" collection.  If
    
# you are not doing a component edit, this will be the main model.
    
# if you are doing a component edit, it will be the open component.
    
# You could also use model.entities which is the top level collection
    
# regardless of whether or not you are doing a component edit.
    
entities = model.active_entities

   

# If you wanted the box to be created as simple top level entities
    
# rather than a Group, you could comment out the following two lines.
    
new_comp_def = Sketchup.active_model.definitions.add(bemerkung)
  
   

 # First we will create a rectangle for the base.  There are a few
    
# variations on the add_face method.  This uses the version that
    
# takes points and automatically creates the edges needed.
    
pts = []
    
pts[0] = [0, 0, 0]
    
pts[1] = [laenge, 0, 0]
    
pts[2] = [laenge, breite, 0]
    
pts[3] = [0, breite, 0]
    
newface = new_comp_def.entities.add_face pts
 

  

# You could use a similar technique to create the other faces of
    
# the box.  For this example, we will use the pushpull method instead.
    
# When you use pushpull, the direction is determined by the direction
    
# of the front of the face.  In order to control the direction and
    
# get the pushpull to go in the direction we want, we first check the
    
# direction of the face normal.  If it is not in the direction that
    
# we want, we will reverse the sign of the distance.
    
newface.reverse! if newface.normal.z < 0
    
    

# Now we can do the pushpull
    
newface.pushpull staerke
    
    


trans = Geom::Transformation.new

comp1_def=Sketchup.active_model.active_entities.add_instance(new_comp_def, trans)




model = Sketchup.active_model
     comp1_def_bb = comp1_def.bounds
laenge1=comp1_def_bb.height
laenge2=comp1_def_bb.depth
laenge3=comp1_def_bb.width.to_f.to_s




comp1_def.set_attribute @Component_dictionary, "bemerkung", bemerkung
comp1_def.set_attribute @Component_dictionary, "artikel", artikel
comp1_def.set_attribute @Component_dictionary, "links", kante_links
comp1_def.set_attribute @Component_dictionary, "rechts", kante_rechts
comp1_def.set_attribute @Component_dictionary, "oben", kante_oben
comp1_def.set_attribute @Component_dictionary, "unten", kante_unten
comp1_def.set_attribute @Component_dictionary, "vorn", belag_vorn
comp1_def.set_attribute @Component_dictionary, "hinten", belag_hinten
comp1_def.set_attribute @Component_dictionary, "_lengthunits", "CENTIMETERS" 




 # Add a new configurable option to Boden.
  # (Any attribute that starts with an underscore
  # is a "meta attribute" that describes behavior.)
  comp1_def.set_attribute @Component_dictionary,'lenx', 'lenxformula'
  comp1_def.set_attribute @Component_dictionary,'_lenx_label', 'LenX'
  comp1_def.set_attribute @Component_dictionary,'_lenx_formlabel', 'FLOAT'
  comp1_def.set_attribute @Component_dictionary,'_lenx_access', 'TEXTBOX'

  comp1_def.set_attribute @Component_dictionary,'leny','lenyformula'
  comp1_def.set_attribute @Component_dictionary,'_leny_label', 'LenY'
  comp1_def.set_attribute @Component_dictionary,'_leny_formlabel', 'FLOAT'
  comp1_def.set_attribute @Component_dictionary,'_leny_access', 'TEXTBOX'

  comp1_def.set_attribute @Component_dictionary,'lenz', 'lenzformula'
  comp1_def.set_attribute @Component_dictionary,'_lenz_label', 'LenZ'
  comp1_def.set_attribute @Component_dictionary,'_lenz_formlabel', 'FLOAT'
  comp1_def.set_attribute @Component_dictionary,'_lenz_access', 'TEXTBOX'


   $dc_observers.get_latest_class.redraw_with_undo
(comp1_def_instance) 



end